#! /bin/bash

# Author: Faisal Abu-Nimeh
# Mod Date: 20140306
# Description: Fetch a specific GetController release from IRFU SVN

# Variables
PASSWORD=ActiveTarget2014
SYSTEM=lnx86
RELEASE_NO=20140408
GETPATH=~/GET-$RELEASE_NO

# Collection of instructions
# Before building from source load these
mkdir -p $GETPATH/software/src
export PREFIX=$GETPATH/software/pkg
export PATH=$PREFIX/bin:$PATH
export PKG_CONFIG_PATH=$PREFIX/lib/pkgconfig:$PKG_CONFIG_PATH

# Install Compound TinyXML
cd $GETPATH/software/src
svn co --username attpc --password $PASSWORD https://dsm-trac.cea.fr/svn/cconfig/TinyXml/trunk TinyXml
cd TinyXml
./autogen.sh
mkdir -p build/$SYSTEM
cd build/$SYSTEM
../../configure --prefix=$PREFIX
make install

# Install CompoundConfig
cd $GETPATH/software/src
svn co --username attpc --password $PASSWORD https://dsm-trac.cea.fr/svn/cconfig/CompoundConfig/tags/CompoundConfig-release-$RELEASE_NO CompoundConfig
cd CompoundConfig
./autogen.sh
mkdir -p build/$SYSTEM
cd build/$SYSTEM
../../configure --prefix=$PREFIX
make install

# Install Utilities
cd $GETPATH/software/src
svn co --username attpc --password $PASSWORD  https://dsm-trac.cea.fr/svn/mordicus/Utilities/tags/Utilities-release-$RELEASE_NO Utilities
cd Utilities
./autogen.sh
mkdir -p build/$SYSTEM
cd build/$SYSTEM
../../configure --prefix=$PREFIX
make install

# Install ConfigWidgets
cd $GETPATH/software/src
svn co --username attpc --password $PASSWORD https://dsm-trac.cea.fr/svn/cconfig/ConfigWidgets/tags/ConfigWidgets-release-$RELEASE_NO ConfigWidgets
cd ConfigWidgets
./autogen.sh
mkdir -p build/$SYSTEM
cd build/$SYSTEM
../../configure --prefix=$PREFIX
make install

# Install MDaq
cd $GETPATH/software/src
svn co --username attpc --password $PASSWORD https://dsm-trac.cea.fr/svn/mordicus/MDaq/tags/MDaq-release-$RELEASE_NO MDaq
cd MDaq
./autogen.sh
mkdir -p build/$SYSTEM
cd build/$SYSTEM
../../configure --prefix=$PREFIX --with-ice=/opt/local
make install

# Install Multiframe
cd $GETPATH/software/src
svn co --username attpc --password $PASSWORD  https://dsm-trac.cea.fr/svn/mordicus/MultiFrame/tags/MultiFrame-release-$RELEASE_NO MultiFrame
cd MultiFrame
./autogen.sh
mkdir -p build/$SYSTEM
cd build/$SYSTEM
../../configure --prefix=$PREFIX
make install

# Install StateMachine
cd $GETPATH/software/src
svn co --username attpc --password $PASSWORD  https://dsm-trac.cea.fr/svn/mordicus/StateMachine/tags/StateMachine-release-$RELEASE_NO StateMachine
cd StateMachine
./autogen.sh
mkdir -p build/$SYSTEM
cd build/$SYSTEM
../../configure --prefix=$PREFIX --with-ice=/opt/local --enable-distributed-sm-libs=all
make install

# Install GetBench
cd $GETPATH/software/src
svn co --username attpc --password $PASSWORD https://dsm-trac.cea.fr/svn/get/GetBench/tags/GetBench-software-release-$RELEASE_NO GetBench
cd GetBench
./autogen.sh
mkdir -p build/$SYSTEM
cd build/$SYSTEM
../../configure --prefix=$PREFIX --with-ice=/opt/local
make install

# Install GetController
cd $GETPATH/software/src
svn co --username attpc --password $PASSWORD https://dsm-trac.cea.fr/svn/get/GetController/tags/GetController-release-$RELEASE_NO GetController
cd GetController
./autogen.sh
mkdir -p build/$SYSTEM
cd build/$SYSTEM
../../configure --prefix=$PREFIX --with-qwt5=/opt/local --with-ice=/opt/local
make install

#Install CoBoFrameViewer
cd $GETPATH/software/src
svn co --username attpc --password $PASSWORD https://dsm-trac.cea.fr/svn/get/CoBoFrameViewer/tags/CoBoFrameViewer-release-$RELEASE_NO CoBoFrameViewer
cd CoBoFrameViewer
./autogen.sh
mkdir -p build/$SYSTEM
cd build/$SYSTEM
../../configure --prefix=$PREFIX --with-qwt5=/opt/local
make install

# Done. load example configs
cd $GETPATH
cp ~/GetScripts/mm* .
cp ~/GetScripts/GETUP .
# mv mmSync ~

mkdir runtime && cd runtime
cp ~/GetScripts/*.ecc .
cp $GETPATH/software/src/GetController/examples/workspace.xcfg .
cp $GETPATH/software/src/GetController/examples/pedestals.xcfg .
ln -s $GETPATH/software/pkg/share/get-bench/format/CoboFormats* .
ln -s $GETPATH/software/pkg/share/get-bench/format/MergedDataFormats* .
ln -s $GETPATH/software/pkg/share/get-bench/config/hardwareDescription_fullCoBoStandAlone.xcfg .
echo "Done installing GET Software."
